==> berty-2.466.2.tar.gz: berty-2.466.2/tool/github-actions/scw-funcs/benchs-hook/README.md <==
# gh-bench-hook

Serverless function that publish benchmark results on a remote repository results without providing a privileged GITHUB_TOKEN.

``` text
                                                    ┌───────────────┬───────────┐
                                                    │Benchmark-Repo             │
                                                    ├ ─ ─ ─ ─ ─ ─ ─ ┘           │
                                                    │    ┌─────────────────┐    │
                                                    │    │                 │    │
                                                    │    │  Action Update  │    │
                               Trigger──────────────┼───▶│    Benchmark    │    │
                                 │                  │    │                 │    │
                                 │                  │    │                 │    │
                                 │                  │    └─────────────────┘    │
                                 │                  │             ▲             │
                                 │                  └─────────────┼─────────────┘
                                 │                                │
                                 │                                │
                                 │                                │
                         ┌──────────────┐                       Fetch
    ┌ ─ ─ ─ ─ ─ ┐        │              │                      Artifact
     priviliged  ────────┼◎ Serverless  │                         │
    └ ─ ─ ─ ─ ─ ┘        │              │                         │
                         └──────────────┘                         │
                                 ▲                                │
                                 │                                │
                                 │                    ┌───────────┼─┬──────────┐
                                 │                    │ Berty-Repo│            │
                                 │                    ├ ─ ─ ─ ─ ─ ▼ ┘          │
                                 │                    │    ┌─────────────┐     │
                                 │                    │    │             │     │
                                 │                    │    │   Action    │     │
                              Webhook─────────────────┼────│  Generate   │     │
                                                      │    │ Benchmarks  │     │
                                                      │    │             │     │
                                                      │    └─────────────┘     │
                                                      │                        │
                                                      └────────────────────────┘
```

Based on https://github.com/scaleway/serverless-scaleway-functions/tree/master/examples/go.

==> berty-2.470.12.tar.gz: berty-2.470.12/tool/github-actions/scw-funcs/benchs-hook/README.md <==
# gh-bench-hook

Serverless function that publish benchmark results on a remote repository results without providing a privileged GITHUB_TOKEN.

``` text
                                                    ┌───────────────┬───────────┐
                                                    │Benchmark-Repo             │
                                                    ├ ─ ─ ─ ─ ─ ─ ─ ┘           │
                                                    │    ┌─────────────────┐    │
                                                    │    │                 │    │
                                                    │    │  Action Update  │    │
                               Trigger──────────────┼───▶│    Benchmark    │    │
                                 │                  │    │                 │    │
                                 │                  │    │                 │    │
                                 │                  │    └─────────────────┘    │
                                 │                  │             ▲             │
                                 │                  └─────────────┼─────────────┘
                                 │                                │
                                 │                                │
                                 │                                │
                         ┌──────────────┐                       Fetch
    ┌ ─ ─ ─ ─ ─ ┐        │              │                      Artifact
     privileged  ────────┼◎ Serverless  │                         │
    └ ─ ─ ─ ─ ─ ┘        │              │                         │
                         └──────────────┘                         │
                                 ▲                                │
                                 │                                │
                                 │                    ┌───────────┼─┬──────────┐
                                 │                    │ Berty-Repo│            │
                                 │                    ├ ─ ─ ─ ─ ─ ▼ ┘          │
                                 │                    │    ┌─────────────┐     │
                                 │                    │    │             │     │
                                 │                    │    │   Action    │     │
                              Webhook─────────────────┼────│  Generate   │     │
                                                      │    │ Benchmarks  │     │
                                                      │    │             │     │
                                                      │    └─────────────┘     │
                                                      │                        │
                                                      └────────────────────────┘
```

Based on https://github.com/scaleway/serverless-scaleway-functions/tree/master/examples/go.
